Module error

Module error 

Errors reported by Minecraft protocol codecs.

This module provides structured context for failures while reading and writing the protocol values implemented by mcproto-codec.

Structs

CodecError
An error produced while reading or writing protocol data.

Enums

CodecErrorKind
Classifies an error reported by a protocol codec.
CodecKind
Identifies the protocol codec that reported an error.
CodecOperation
Identifies whether an error occurred while decoding or encoding data.
ContextRequirement
Identifies information required by a contextual codec.
InvalidEncodingReason
Describes why encoded protocol data is invalid.