#[non_exhaustive]pub enum CodecErrorKind {
Io,
UnexpectedEof,
InvalidEncoding(InvalidEncodingReason),
}Expand description
Classifies an error reported by a protocol codec.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
An I/O error other than an unexpected end of input occurred.
UnexpectedEof
A read ended before the codec received all required bytes.
InvalidEncoding(InvalidEncodingReason)
The data could not be decoded or encoded according to the codec’s format or limits.