Module io

Module io 

Counted I/O helpers for protocol codecs.

These functions provide the completion guarantees of Read::read_exact and Write::write_all while attaching codec metadata and byte progress to any CodecError they return.

Functions

read_exact_counted
Fills buffer from reader and tracks progress for codec errors.
write_all_counted
Writes all of buffer to writer and tracks progress for codec errors.