Errors reported by Minecraft protocol codecs.
This module provides structured context for failures while reading and
writing the protocol values implemented by mcproto-codec.
Structs
- Codec
Error - An error produced while reading or writing protocol data.
Enums
- Codec
Error Kind - Classifies an error reported by a protocol codec.
- Codec
Kind - Identifies the protocol codec that reported an error.
- Codec
Operation - Identifies whether an error occurred while decoding or encoding data.
- Context
Requirement - Identifies information required by a contextual codec.
- Invalid
Encoding Reason - Describes why encoded protocol data is invalid.