Module error

Module error 

Structs

CodecError
An error produced while reading or writing protocol data.

Enums

CodecErrorKind
Classifies an error reported by a protocol codec.
CodecKind
Identifies the protocol codec that reported an error.
CodecOperation
Identifies whether an error occurred while decoding or encoding data.
InvalidEncodingReason
Describes why encoded protocol data is invalid.