pub struct CodecError {
pub kind: CodecErrorKind,
/* private fields */
}Fields
kind: CodecErrorKindImplementations
Sourceimpl CodecError
impl CodecError
pub const fn kind(&self) -> CodecErrorKind
pub const fn codec(&self) -> CodecKind
pub fn context(&self) -> Option<CodecKind>
pub fn contexts(&self) -> &[CodecKind]
pub const fn operation(&self) -> CodecOperation
Sourcepub const fn bytes_processed(&self) -> usize
pub const fn bytes_processed(&self) -> usize
Returns the number of bytes successfully processed before the error.
pub fn io_error(&self) -> Option<&Error>
Sourcepub fn with_context(self, context: CodecKind) -> Self
pub fn with_context(self, context: CodecKind) -> Self
Adds the outer codec that was active when this error occurred.
pub fn from_read_error( codec: CodecKind, bytes_processed: usize, source: Error, ) -> Self
pub fn from_write_error( codec: CodecKind, bytes_processed: usize, source: Error, ) -> Self
Sourcepub const fn invalid_encoding(
codec: CodecKind,
bytes_processed: usize,
reason: InvalidEncodingReason,
) -> Self
pub const fn invalid_encoding( codec: CodecKind, bytes_processed: usize, reason: InvalidEncodingReason, ) -> Self
Tips:encoding是编码格式,不是encode过程
pub const fn invalid_encoding_for_operation( codec: CodecKind, operation: CodecOperation, bytes_processed: usize, reason: InvalidEncodingReason, ) -> Self
pub fn invalid_encoding_for_operation_with_source( codec: CodecKind, operation: CodecOperation, bytes_processed: usize, reason: InvalidEncodingReason, source: impl Error + Send + Sync + 'static, ) -> Self